pitchtools.TwelveToneRow
========================

.. abjad-lineage:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow

.. autoclass:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.alpha
      ~abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.count
      ~abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.custom_identifier
      ~abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.from_selection
      ~abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.has_duplicates
      ~abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.index
      ~abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.invert
      ~abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.is_equivalent_under_transposition
      ~abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.item_class
      ~abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.make_notes
      ~abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.multiply
      ~abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.retrograde
      ~abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.rotate
      ~abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.transpose
      ~abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.__add__
      ~abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.__contains__
      ~abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.__eq__
      ~abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.__format__
      ~abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.__getitem__
      ~abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.__getslice__
      ~abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.__hash__
      ~abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.__iter__
      ~abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.__len__
      ~abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.__makenew__
      ~abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.__mul__
      ~abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.__ne__
      ~abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.__repr__
      ~abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.__rmul__
      ~abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.__str__

Bases
-----

- :py:class:`pitchtools.PitchClassSegment <abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment>`

- :py:class:`pitchtools.Segment <abjad.tools.pitchtools.Segment.Segment>`

- :py:class:`datastructuretools.TypedTuple <abjad.tools.datastructuretools.TypedTuple.TypedTuple>`

- :py:class:`datastructuretools.TypedCollection <abjad.tools.datastructuretools.TypedCollection.TypedCollection>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.has_duplicates
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.item_class
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.custom_identifier
   :noindex:

Methods
-------

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.alpha
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.count
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.index
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.invert
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.is_equivalent_under_transposition
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.make_notes
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.multiply
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.retrograde
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.rotate
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.transpose
   :noindex:

Class methods
-------------

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.from_selection
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.__add__
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.__contains__
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.__format__
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.__getitem__
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.__getslice__
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.__hash__
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.__iter__
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.__len__
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.__makenew__
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.__mul__
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.__repr__
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.__rmul__
   :noindex:

.. automethod:: abjad.tools.pitchtools.TwelveToneRow.TwelveToneRow.__str__
   :noindex:
